@@ -422,6 +422,8 @@ struct drumkv1_del
 	float *delay;
 	float *feedb;
 	float *bpm;
+	float *bpmsync, bpmsync0;
+	float *bpmhost;
 };
 
 
@@ -851,6 +853,9 @@ drumkv1_impl::drumkv1_impl ( uint16_t iChannels, uint32_t iSampleRate )
 	// compressors none yet
 	m_comp = 0;
 
+	// no delay sync yet
+	m_del.bpmsync0 = 0.0f;
+
 	// number of channels
 	setChannels(iChannels);
 
@@ -1112,6 +1117,8 @@ void drumkv1_impl::setParamPort ( drumkv1::ParamIndex index, float *pfParam )
 	case drumkv1::DEL1_DELAY:     m_del.delay     = pfParam; break;
 	case drumkv1::DEL1_FEEDB:     m_del.feedb     = pfParam; break;
 	case drumkv1::DEL1_BPM:       m_del.bpm       = pfParam; break;
+	case drumkv1::DEL1_BPMSYNC:   m_del.bpmsync   = pfParam; break;
+	case drumkv1::DEL1_BPMHOST:   m_del.bpmhost   = pfParam; break;
 	case drumkv1::DYN1_COMPRESS:  m_dyn.compress  = pfParam; break;
 	case drumkv1::DYN1_LIMITER:   m_dyn.limiter   = pfParam; break;
 	default:
@@ -1153,6 +1160,8 @@ float *drumkv1_impl::paramPort ( drumkv1::ParamIndex index )
 	case drumkv1::DEL1_DELAY:     pfParam = m_del.delay;     break;
 	case drumkv1::DEL1_FEEDB:     pfParam = m_del.feedb;     break;
 	case drumkv1::DEL1_BPM:       pfParam = m_del.bpm;       break;
+	case drumkv1::DEL1_BPMSYNC:   pfParam = m_del.bpmsync;   break;
+	case drumkv1::DEL1_BPMHOST:   pfParam = m_del.bpmhost;   break;
 	case drumkv1::DYN1_COMPRESS:  pfParam = m_dyn.compress;  break;
 	case drumkv1::DYN1_LIMITER:   pfParam = m_dyn.limiter;   break;
 	default:
@@ -1593,6 +1602,15 @@ void drumkv1_impl::process ( float **ins, float **outs, uint32_t nframes )
 		pv = pv_next;
 	}
 
+	// delay sync toggle
+	if (int(*m_del.bpmsync) != int(m_del.bpmsync0)) {
+		float *del_bpm = m_del.bpm; 
+		float *del_bpmhost = m_del.bpmhost;
+		m_del.bpmsync0 = *m_del.bpmsync;
+		m_del.bpmhost = del_bpm;
+		m_del.bpm = del_bpmhost;
+	}
+
 	// effects
 
 	for (k = 0; k < m_iChannels; ++k) {
