@@ -130,6 +130,9 @@ protected slots:
 	// Swap params A/B.
 	void swapParams(bool bOn);
 
+	// Delay BPM change.
+	void bpmSyncChanged();
+
 	// Menu actions.
 	void helpAbout();
 	void helpAboutQt();
@@ -165,6 +168,9 @@ protected:
 	// Param port method.
 	virtual void updateParam(drumkv1::ParamIndex index, float fValue) const = 0;
 
+	// Update local tied widgets.
+	void updateParamEx(drumkv1::ParamIndex index, float fValue);
+
 	// Dirty flag (overridable virtual) methods.
 	virtual void updateDirtyPreset(bool bDirtyPreset);
 
