@@ -22,17 +22,7 @@
 #ifndef __drumkv1widget_config_h
 #define __drumkv1widget_config_h
 
-#include "config.h"
-
-#define DRUMKV1_TITLE	PACKAGE_NAME
-#define DRUMKV1_VERSION	PACKAGE_VERSION
-
-#define DRUMKV1_SUBTITLE     "an old-school drum-kit sampler."
-#define DRUMKV1_WEBSITE      "http://drumkv1.sourceforge.net"
-#define DRUMKV1_COPYRIGHT    "Copyright (C) 2012-2013, rncbc aka Rui Nuno Capela. All rights reserved."
-
-#define DRUMKV1_DOMAIN	"rncbc.org"
-
+#include "drumkv1_config.h"
 
 #include <QSettings>
 #include <QStringList>
