@@ -1,7 +1,7 @@
 // drumkv1widget_preset.h
 //
 /****************************************************************************
-   Copyright (C) 2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -44,6 +44,9 @@ public:
 	void setPreset(const QString& sPreset);
 	QString preset() const;
 
+	void setDirtyPreset(bool bDirtyPreset);
+	bool isDirtyPreset() const;
+
 	void clearPreset();
 	bool queryPreset();
 
@@ -59,14 +62,13 @@ signals:
 public slots:
 
 	void initPreset();
-	void dirtyPreset();
 	void stabilizePreset();
 
 protected slots:
 
 	void newPreset();
 	void openPreset();
-	void changePreset(const QString&);
+	void activatePreset(const QString&);
 	void savePreset();
 	void deletePreset();
 	void resetPreset();
